#!/usr/bin/env node
Object.defineProperty(exports, "__esModule", { value: true });
const spawn_process_promise_1 = require("./../spawn_process_promise");
// Load scoped modules.
const dotenv_1 = require("@player1os/dotenv");
const execute_promise_1 = require("@player1os/execute-promise");
// Load npm modules.
const fse = require("fs-extra");
const recursiveReaddirSync = require("recursive-readdir-sync");
// Load node modules.
const path = require("path");
// Load the env variables.
const { env, rawEnv } = dotenv_1.default();
execute_promise_1.default(async () => {
    await spawn_process_promise_1.default('tsc', [
        '-p', './tsconfig-create.json',
    ]);
    await spawn_process_promise_1.default('ts-config-rewrite-paths', [
        './build', '...' + '/src/', '.js',
    ]);
    await Promise.all(recursiveReaddirSync(path.join(process.cwd(), './build'))
        .map(async (filePath) => {
        // Verify that the current file has the correct extension.
        if (path.extname(filePath) !== '.js') {
            return;
        }
        const content = await fse.readFile(filePath, { encoding: 'utf-8' });
        const originalLength = content.length;
        const lines = content.replace(/\r/g, '').split('\n');
        const lineDelimiter = originalLength > content.length
            ? '\r\n'
            : '\n';
        // Verify that the current file is an executable script.
        if (lines[0] !== '#!/usr/bin/env node') {
            return;
        }
        lines.splice(2, 0, ...[
            `global._env_ = ${JSON.stringify(env)};`,
            `global._raw_env_ = ${JSON.stringify(rawEnv)};`,
            `process.env = Object.assign({}, _raw_env_, process.env);`,
            `require('@player1os/node-js-application-runtime');`,
        ]);
        await fse.writeFile(filePath, lines.join(lineDelimiter), { encoding: 'utf-8' });
    }));
    console.log('OK'); // tslint:disable-line:no-console
});
//# sourceMappingURL=build.js.map