#!/usr/bin/env node
Object.defineProperty(exports, "__esModule", { value: true });
const spawn_process_promise_1 = require("./../spawn_process_promise");
// Load scoped modules.
const data_type_utility_1 = require("@player1os/data-type-utility");
const execute_promise_1 = require("@player1os/execute-promise");
// Load npm modules.
const fse = require("fs-extra");
// Load node modules.
const path = require("path");
execute_promise_1.default(async () => {
    // Update
    await spawn_process_promise_1.default('git', ['pull']);
    await spawn_process_promise_1.default('npm', ['prune']);
    await spawn_process_promise_1.default('npm', ['install']);
    // Build
    await spawn_process_promise_1.default('npm', ['run', 'clean']);
    await spawn_process_promise_1.default('npm', ['run', 'build']);
    // Install
    await fse.copy('package.json', 'build/package.json');
    await spawn_process_promise_1.default('npm', ['install', '--only=production'], {
        cwd: path.join(process.cwd(), 'build'),
    });
    await fse.remove('build/package.json');
    await fse.remove('build/package-lock.json');
    // Migrate
    await spawn_process_promise_1.default('npm', ['run', 'migrate']);
    // Backup
    await fse.ensureDir('dist');
    if (fse.existsSync('dist/current')) {
        await fse.move('dist/current', `dist/${data_type_utility_1.date.toUtcDateTimeString(new Date(), {
            dateDelimiter: '',
            timeDelimiter: '',
            portionDelimiter: '_',
        })}`);
    }
    // Swap
    await fse.move('build', 'dist/current');
    // Reload
    await spawn_process_promise_1.default('pm2', ['startOrReload', 'pm2.json', '--update-env']);
    const pm2Config = await fse.readJsonSync('pm2.json');
    await Promise.all(pm2Config.apps.map(async (configItem) => {
        await spawn_process_promise_1.default('pm2', ['reset', configItem.name]);
    }));
});
//# sourceMappingURL=deploy.js.map